import { View, Input, Button } from '@tarojs/components'
import { useCallback, useEffect, useMemo, useRef, useState, } from 'react'
import { mpenumsaleorderstatus, OrderListApi } from '@/api/order'
import OrderStatusList from './components/orderStatusList'
import Search from '@/components/search'
import { dataLoadingStatus, getFilterData } from '@/common/util'
import styles from "./index.module.scss"
import classnames from "classnames";
import Popup from '@/components/popup'
import InfiniteScroll from '@/components/infiniteScroll'
import Taro, { useDidShow } from '@tarojs/taro'
import ItemList from './components/itemList'

export default () => {
  //页码和页数
  const [searchField, setSearchField] = useState<{ status: number | unknown; page: number; size: number; name: string }>({
    status: -1,
    page: 1,
    size: 10,
    name: '',
  })

  //获取订单列表
  const { fetchData: listFetchData, state: orderState } = OrderListApi()
  const [orderData, setOrderData] = useState<{ list: any[]; total: number }>({ list: [], total: 0 })
  const getOrderList = async () => {
    let res = await listFetchData({
      ...getFilterData(searchField),
      ...getFilterData(searchObj)
    })
    setOrderData((e) => ({ ...e, list: res.data?.list, total: res.data?.total }))
    setshowPopup(false)
    setRefresherTriggeredStatus(() => false)
  }




  //列表下拉刷新
  const [refresherTriggeredStatus, setRefresherTriggeredStatus] = useState(false)
  const getRefresherRefresh = async () => {
    pageNum.current.size = 1
    setRefresherTriggeredStatus(true)
    setSearchField((val) => ({ ...val, size: 10 }))
  }
  //数据加载状态
  const statusMore = useMemo(() => {
    console.log({ list: orderData.list, total: orderData.total, status: orderState.loading }, '{ list: orderData.list, total: orderData.total, status: orderState.loading }')
    return dataLoadingStatus({ list: orderData.list, total: orderData.total, status: orderState.loading })
  }, [orderData, orderState])

  //上拉加载数据
  const pageNum = useRef({ size: searchField.size, page: searchField.page })
  const getScrolltolower = useCallback(() => {
    if (orderData.list.length < orderData.total) {
      pageNum.current.page++
      const size = pageNum.current.size * pageNum.current.page
      setSearchField({ ...searchField, size })
    }
  }, [orderData])

  // //获取订单状态
  const { fetchData: orderStatusListFetchData } = mpenumsaleorderstatus()
  const [statusList, setStatusList] = useState<any[]>([{ id: -1, name: '全部' }])
  const getOrderStatusList = async () => {
    let res = await orderStatusListFetchData()
    setStatusList((e) => [...e, ...res.data.list])
  }

  //监听筛选条件变化
  useEffect(() => {
    if (searchField.status != null) getOrderList()
  }, [searchField])

  // //状态改变
  const changeStatus = useCallback((e) => {
    pageNum.current.page = 1
    setSearchField((value) => ({ ...value, status: e, size: 10 }))

    console.log(e, '123123')
    setOrderData(() => ({ list: [], total: 0 }))
  }, [])

  //输入了搜索关键字
  const getSearchData = useCallback((e) => {
    pageNum.current.page = 1
    setOrderData(() => ({ list: [], total: 0 }))
    setSearchField((val) => ({ ...val, name: e, size: 10 }))
  }, [])
  //筛选内容展示
  const [showPopup, setshowPopup] = useState(false)
  const showSelctPopup = () => {
    setshowPopup(true)
  }
  //关闭筛选内容展示
  const closePopup = () => {
    setshowPopup(false)
  }


  useDidShow(() => {

    //获取选择的客户
    let pages = Taro.getCurrentPages();
    let currPage = pages[pages.length - 1]; // 获取当前页面
    console.log(currPage.data, '8888')

    setsearchObj((e) => ({
      ...e,
      purchaser_id: currPage.data?.clientId ? currPage.data?.clientId : '',
      clientName: currPage.data?.clientName ? currPage.data?.clientName : '',
      sale_user_id: currPage.data?.saleuserId ? currPage.data?.saleuserId : '',
      saleuserName: currPage.data?.saleuserName ? currPage.data?.saleuserName : '',
    }))
  })

  interface filterObj {
    purchaser_id?: string | number,
    clientName?: string,
    sale_user_id?: string | number,
    saleuserName?: string,
    orderNo?: string | undefined,
    sale_mode?: Number | undefined,
    shipment_mode?: Number | undefined
  }

  //筛选参数
  const [searchObj, setsearchObj] = useState<filterObj>({
    purchaser_id: '',
    clientName: '',
    sale_user_id: '',
    saleuserName: '',
    orderNo: '',
    sale_mode: undefined,
    shipment_mode: undefined
  })
  // 跳转选择客户
  const navTo = (index) => {
    if (index === 1) {
      Taro.navigateTo({
        url: '/pages/customerPage/index?clientId=' + searchObj?.purchaser_id
      })
    } else {
      Taro.navigateTo({
        url: '/pages/saleuserPage/index?saleuserId=' + searchObj?.sale_user_id
      })
    }
  }
  //订单号输入框
  const handInput = (eq) => {
    setsearchObj((e) => ({ ...e, orderNo: eq.detail.value }))
  }

  //订单类型
  const [modeList, setModeList] = useState<any[]>([{ id: -1, name: '不限' }, { id: 0, name: '大货' }, { id: 1, name: '剪版' }, { id: 2, name: '散剪' }])
  //选择订单类型
  const handCheckMode = (item) => {
    modeList.map(it => {
      if (it.id === item.id) {
        it.checked = true
      } else {
        it.checked = false
      }
      return it
    })
    setModeList([...modeList])
    setsearchObj((e) => ({ ...e, sale_mode: item.id }))
  }

  ///发货方式类型
  const [deliveryList, setdeliveryList] = useState<any[]>([{ id: -1, name: '不限' }, { id: 1, name: '自提' }, { id: 2, name: '物流' }])
  //选择发货方式类型
  const handCheckDelivery = (item) => {
    deliveryList.map(it => {
      if (it.id === item.id) {
        it.checked = true
      } else {
        it.checked = false
      }
      return it
    })
    setdeliveryList([...deliveryList])
    setsearchObj((e) => ({ ...e, shipment_mode: item.id }))
  }
  //是否不允许确认筛选
  const isDisabled = useMemo(() => {
    if (searchObj.clientName !== '' ||
      searchObj.orderNo !== '' ||
      searchObj.saleuserName !== '' ||
      searchObj.sale_mode !== undefined ||
      searchObj.shipment_mode !== undefined
    ) {
      return false
    } else {
      return true
    }
  }, [searchObj])

  //重置
  const handReset = () => {
    setsearchObj({
      purchaser_id: '',
      clientName: '',
      sale_user_id: '',
      saleuserName: '',
      orderNo: '',
      sale_mode: undefined,
      shipment_mode: undefined
    })
  }
  //确认筛选
  const handSure = async () => {
    getOrderList()
  }
  //扫描
  const handScan = () => {
    Taro.scanCode({
      success(res) {
        setsearchObj((e) => ({ ...e, orderNo: res.result }))
      },
      fail(res) {
        console.log(res);
      },
    });
  }

  useEffect(() => {
    getOrderStatusList()
  }, [])
  return (
    <View>
      <Search placeholder='搜索商品/名称/颜色/订单号' showBtn={false} changeOnSearch={getSearchData} debounceTime={300} >
        <View className={styles.flexBox} onClick={() => showSelctPopup()}>
          <View className={classnames('iconfont', 'icon-shaixuan', !isDisabled ? styles.icon_shaixuan : styles.activeshaixuan)}></View>
          <View className={classnames(isDisabled ? styles.shaixuan : styles.activeshai)}>筛选</View>
        </View>
      </Search>
      <OrderStatusList list={statusList} onSelect={changeStatus} defaultId={-1} />
      <View className={styles.order_list}>
        <InfiniteScroll
          statusMore={statusMore}
          selfonScrollToLower={getScrolltolower}
          refresherEnabled={true}
          refresherTriggered={refresherTriggeredStatus}
          selfOnRefresherRefresh={getRefresherRefresh}>
          {orderData?.list?.map((item, index) => {
            return (
              <View key={item.id} className={styles.order_item_con}>
                <ItemList obj={item} key={index}></ItemList>
              </View>
            )
          })}
        </InfiniteScroll>
      </View>
      <Popup title={'筛选订单'} show={showPopup} onClose={() => closePopup()}>
        <View className={styles.popupBox}>
          <View className={styles.topBox}>
            <View className={styles.leftTop} onClick={() => navTo(1)}>
              <View className={styles.lefttopTitle}>客户信息</View>
              <View className={classnames(searchObj.clientName === '' ? styles.lefttopSelectBox : styles.activelefttopSelectBox)}>
                <View className={styles.lefttopSelectName}>{searchObj.clientName === '' ? '请选择客户' : searchObj.clientName}</View>
                <View className={classnames('iconfont', 'icon-more', styles.icon_more)}></View>
              </View>
            </View>
            <View className={styles.leftTop} onClick={() => navTo(2)}>
              <View className={styles.lefttopTitle}>业务员</View>
              <View className={classnames(searchObj.saleuserName === '' ? styles.lefttopSelectBox : styles.activelefttopSelectBox)}>
                <View className={styles.lefttopSelectName}>{searchObj.saleuserName === '' ? '请选择客户' : searchObj.saleuserName}</View>
                <View className={classnames('iconfont', 'icon-more', styles.icon_more)}></View>
              </View>
            </View>
          </View>
          <View className={styles.secondBox}>
            <View className={styles.secondTopfont}>订单单号</View>
            <View className={styles.inputBox}>
              <Input onInput={(e) => { handInput(e) }} placeholderStyle='color:#000000; font-size:26rpx' className={styles.orderInput} value={searchObj.orderNo} placeholder={'请输入或扫描条形码'}></Input>
              <View className={classnames('iconfont', 'icon-saomiao', styles.saomiao)} onClick={() => { handScan() }}></View>
            </View>
          </View>
          <View className={styles.thirdBox}>
            <View className={styles.thirdTopfont}>订单类型</View>
            <View className={styles.flexModebox}>
              {
                modeList.map((item, index) => {
                  return (
                    <View onClick={() => { handCheckMode(item) }} className={classnames(item.checked ? styles.activemodeBox : styles.modeBox)} key={index}>{item.name}</View>
                  )
                })
              }
            </View>
          </View>
          <View className={styles.thirdBox}>
            <View className={styles.thirdTopfont}>发货方式</View>
            <View className={styles.flexModebox}>
              {
                deliveryList.map((item, index) => {
                  return (
                    <View onClick={() => { handCheckDelivery(item) }} className={classnames(item.checked ? styles.activemodeBox : styles.modeBox)} key={index}>{item.name}</View>
                  )
                })
              }
            </View>
          </View>
          <View>{isDisabled}</View>
          <View style={{ height: '160rpx' }}></View>

          <View className={styles.bottomBox}>

            <Button className={styles.resetBox} onClick={() => { handReset() }}> 重置</Button >
            <Button className={classnames(isDisabled ? styles.button : styles.activeButton)} disabled={isDisabled} onClick={() => { handSure?.() }}> 确认</Button >
          </View>
        </View>
      </Popup>
    </View>
  )
}
