import { isEmptyObject } from '@/common/common'
import { Button, View, Image, Text } from '@tarojs/components'
import { FC, memo, useMemo, useState } from 'react'
import styles from './index.module.scss'
import defaultAvatar from '../../styles/image/defaultAvatar.png'
import NormalButton from '@/components/normalButton'
import Tag from '@/components/tag'
import Divider from '@/components/Divider'
import LayoutBlock from '@/components/layoutBlock'
import IconCard from '@/components/iconCard'
import IconFont from '@/components/iconfont'

type IconfontName = Parameters<typeof IconFont>['0']['name']
type IconCardType = {
  iconName: IconfontName,
  name: string,
  path: string
}

// 用户信息
const UserInfo: FC = () => {
  const [userInfo, setUserInfo] = useState({
    avatarUrl: '',
    username: '',
    userno: '',
  })
  

  const feature: IconCardType[] = [
    {
      iconName: 'icon-lingquseka',
      name: '领取色卡',
      path: '',
    },
    {
      iconName: 'icon-pandiansaoma',
      name: '盘点扫码',
      path: '',
    },
    {
      iconName: 'icon-fahuoliebiao',
      name: '发货列表',
      path: '',
    },
    {
      iconName: 'icon-yaoqingma',
      name: '邀请码',
      path: '',
    },
    {
      iconName: 'icon-tihuoliebiao',
      name: '提货列表',
      path: '',
    },
    {
      iconName: 'icon-shouhouzhongxin',
      name: '退货退款',
      path: '',
    },
    {
      iconName: 'icon-shoukuanliebiao',
      name: '收款列表',
      path: '',
    },
    {
      iconName: 'icon-shoukuanliebiao',
      name: '客户列表',
      path: '',
    },
  ]

  const fabric: IconCardType[] = [
    {
      iconName: 'icon-yansequyang',
      name: '颜色取样',
      path: '',
    },
    {
      iconName: 'icon-qusechazhao',
      name: '取色查找',
      path: '',
    },
    {
      iconName: 'icon-yangpinduibi',
      name: '样品对比',
      path: '',
    },
  ]

  const statisticAnalysis: IconCardType[] = [
    {
      iconName: 'icon-xiaoshou',
      name: '销售',
      path: '',
    },
    {
      iconName: 'icon-duizhang',
      name: '对账',
      path: '',
    },
    {
      iconName: 'icon-yuncangkucun',
      name: '云仓库存',
      path: '',
    },
    {
      iconName: 'icon-qianzhicangkucun',
      name: '前置仓库存',
      path: '',
    },
  ]

  const handleLogout = () => {}

  return (
    <>
      <LayoutBlock circle>
        <View className={styles.topBar}>
          <View className={styles.left}>
            <UserAvatar src={userInfo.avatarUrl} />
          </View>
          <View className={styles.middle}>
            <Text className={styles.username}>杨子杰</Text>
            <Text className={styles.userno}>064</Text>
          </View>
          <View className={styles.right}>
            <NormalButton type='primary' circle size='normal' onClick={handleLogout}>
              退出登录
            </NormalButton>
          </View>
        </View>
        <View className={styles.bottomBar}>
          <Tag type='primary' size='normal' circle customStyle={{ marginRight: '10px' }}>
            IT部门
          </Tag>
          <Divider direction='vertical'></Divider>
          <Text className={styles.userTitle}>IT-开发总监</Text>
        </View>
      </LayoutBlock>
      <LayoutBlock circle>
        <View className={styles.layoutTitle}>功能特色</View>
        <View className={styles['grid-container']}>
          {feature.map((item) => {
            return <IconCard iconName={item.iconName} title={item.name}></IconCard>
          })}
        </View>
      </LayoutBlock>
      <LayoutBlock circle>
        <View className={styles.layoutTitle}>布料取色</View>
        <View className={styles['grid-container']}>
          {fabric.map((item) => {
            return <IconCard iconName={item.iconName} title={item.name}></IconCard>
          })}
        </View>
      </LayoutBlock>
      <LayoutBlock circle>
        <View className={styles.layoutTitle}>统计分析</View>
        <View className={styles['grid-container']}>
          {statisticAnalysis.map((item) => {
            return <IconCard iconName={item.iconName} title={item.name}></IconCard>
          })}
        </View>
      </LayoutBlock>
      {/* <LayoutBlock circle>
        <View className={styles.layoutTabBar}>
          <View className={styles.layoutTitle}>客户列表</View>
          <View className={styles.layoutDescription}>查看全部客户 ▶</View>
        </View>
        asdfasdfasdfas 
      </LayoutBlock> */}
    </>
  )
}
// 用户头像
const UserAvatar = ({ src }) => {
  return (
    <View className={styles.userAvatar}>
      <Image className='full-100' src={src ? src : defaultAvatar} />
      {src ? null : <Text className={styles['userAvatar-text']}>编辑</Text>}
    </View>
  )
}

// 我的
const User = () => {
  return (
    <>
      <View className={styles.main}>
        <UserInfo />
      </View>
    </>
  )
}

export default User
